@@ -23,7 +23,7 @@ use integer; # vroom!
 use strict;
 use Carp ();
 use vars qw($VERSION );
-$VERSION = '3.22';
+$VERSION = '3.24';
 #use constant DEBUG => 7;
 BEGIN {
   require Pod::Simple;
@@ -123,8 +123,21 @@ sub parse_lines {             # Usage: $parser->parse_lines(@lines)
       }
     }
 
-    if(!$self->{'encoding'}) {
-      $self->_try_encoding_guess($line)
+    # Try to guess encoding. Inlined for performance reasons.
+    if(!$self->{'parse_characters'} && !$self->{'encoding'}
+      && ($self->{'in_pod'} || $line =~ /^=/s)
+      && $line =~ /[^\x00-\x7f]/
+    ) {
+      my $encoding = $line =~ /^[\x00-\x7f]*[\xC0-\xFD][\x80-\xBF]/ ? 'UTF-8' : 'ISO8859-1';
+      $self->_handle_encoding_line( "=encoding $encoding" );
+      $self->{'_transcoder'} && $self->{'_transcoder'}->($line);
+
+      my ($word) = $line =~ /(\S*[^\x00-\x7f]\S*)/;
+
+      $self->whine(
+        $self->{'line_count'},
+        "Non-ASCII character seen before =encoding in '$word'. Assuming $encoding"
+      );
     }
 
     DEBUG > 5 and print "# Parsing line: [$line]\n";
@@ -179,6 +192,7 @@ sub parse_lines {             # Usage: $parser->parse_lines(@lines)
 
     # HERE WE CATCH =encoding EARLY!
     if( $line =~ m/^=encoding\s+\S+\s*$/s ) {
+      next if $self->parse_characters;   # Ignore this line
       $line = $self->_handle_encoding_line( $line );
     }
 
@@ -272,6 +286,8 @@ sub parse_lines {             # Usage: $parser->parse_lines(@lines)
 sub _handle_encoding_line {
   my($self, $line) = @_;
   
+  return if $self->parse_characters;
+
   # The point of this routine is to set $self->{'_transcoder'} as indicated.
 
   return $line unless $line =~ m/^=encoding\s+(\S+)\s*$/s;
@@ -398,28 +414,6 @@ sub _handle_encoding_second_level {
   return;
 }
 
-sub _try_encoding_guess {
-  my ($self,$line) = @_;
-
-  if(!$self->{'in_pod'}  and  $line !~ /^=/m) {
-    return;  # don't whine about non-ASCII bytes in code/comments
-  }
-
-  return unless $line =~ /[^\x00-\x7f]/;  # Look for non-ASCII byte
-
-  my $encoding = $line =~ /[\xC0-\xFD][\x80-\xBF]/ ? 'UTF-8' : 'ISO8859-1';
-  $self->_handle_encoding_line( "=encoding $encoding" );
-  $self->{'_transcoder'} && $self->{'_transcoder'}->($line);
-
-  my ($word) = $line =~ /(\S*[^\x00-\x7f]\S*)/;
-
-  $self->whine(
-    $self->{'line_count'},
-    "Non-ASCII character seen before =encoding in '$word'. Assuming $encoding"
-  );
-
-}
-
 #~`~`~`~`~`~`~`~`~`~`~`~`~`~`~`~`~`~`~`~`~`~`~`~`~`~`~`~`~`~`~`~`~`~`~`~`~`
 
 {
@@ -669,6 +663,10 @@ sub _ponder_paragraph_buffer {
           } elsif($item_type eq 'number' or $item_type eq 'bullet') {
             die "Unknown item type $item_type"
              unless $item_type eq 'number' or $item_type eq 'bullet';
+            $self->whine(
+              $para->[1]{'start_line'},
+              "Expected text matching /\\s+[^\\*\\d]/ after '=item'"
+            );
             # Undo our clobbering:
             push @$para, $para->[1]{'~orig_content'};
             delete $para->[1]{'number'};
@@ -1277,6 +1275,10 @@ sub _ponder_item {
     } elsif($item_type eq 'number' or $item_type eq 'bullet') {
       die "Unknown item type $item_type"
        unless $item_type eq 'number' or $item_type eq 'bullet';
+      $self->whine(
+          $para->[1]{'start_line'},
+          "Expected text matching /\\s+[^\\*\\d]/ after '=item'"
+      );
       # Undo our clobbering:
       push @$para, $para->[1]{'~orig_content'};
       delete $para->[1]{'number'};
